@@ -1,21 +1,8 @@
 /*
-  Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
-  Copyright (C) 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2010 Casey Link <unnamedrambler@gmail.com>
+  SPDX-FileCopyrightText: 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "attendeeeditor.h"
@@ -34,7 +21,7 @@ AttendeeEditor::AttendeeEditor(QWidget *parent)
 
 void AttendeeEditor::slotLineAdded(KPIM::MultiplyingLine *line)
 {
-    AttendeeLine *att = qobject_cast<AttendeeLine *>(line);
+    auto *att = qobject_cast<AttendeeLine *>(line);
     if (!att) {
         return;
     }
@@ -51,7 +38,7 @@ void AttendeeEditor::slotCalculateTotal()
 
     const QList<KPIM::MultiplyingLine *> listLines = lines();
     for (KPIM::MultiplyingLine *line : listLines) {
-        AttendeeLine *att = qobject_cast<AttendeeLine *>(line);
+        auto *att = qobject_cast<AttendeeLine *>(line);
         if (att) {
             if (att->isEmpty()) {
                 ++empty;
@@ -69,7 +56,7 @@ void AttendeeEditor::slotCalculateTotal()
 
 AttendeeData::List AttendeeEditor::attendees() const
 {
-    const QList<KPIM::MultiplyingLineData::Ptr> dataList = allData();
+    const QVector<KPIM::MultiplyingLineData::Ptr> dataList = allData();
     AttendeeData::List attList;
     //qCDebug(INCIDENCEEDITOR_LOG) << "num attendees:" << dataList.size();
     for (const KPIM::MultiplyingLineData::Ptr &datum : dataList) {
@@ -96,7 +83,7 @@ void AttendeeEditor::setActions(AttendeeLine::AttendeeActions actions)
 {
     const QList<KPIM::MultiplyingLine *> listLines = lines();
     for (KPIM::MultiplyingLine *line : listLines) {
-        AttendeeLine *att = qobject_cast<AttendeeLine *>(line);
+        auto *att = qobject_cast<AttendeeLine *>(line);
         att->setActions(actions);
     }
 }
