@@ -1,26 +1,13 @@
 /*
-  Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
-  Copyright (c) 2009-2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Casey Link <unnamedrambler@gmail.com>
+  SPDX-FileCopyrightText: 2009-2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 
   Based on old attendeeeditor.cpp:
-  Copyright (c) 2000,2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (c) 2007 Volker Krause <vkrause@kde.org>
+  SPDX-FileCopyrightText: 2000, 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2007 Volker Krause <vkrause@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "incidenceattendee.h"
@@ -32,7 +19,7 @@
 #include "editorconfig.h"
 #include "incidencedatetime.h"
 #include "schedulingdialog.h"
-#include "CalendarSupport/FreeBusyItemModel"
+#include <CalendarSupport/FreeBusyItemModel>
 #include "ui_dialogdesktop.h"
 
 #include <Akonadi/Contact/ContactGroupExpandJob>
@@ -56,7 +43,6 @@ using namespace IncidenceEditorNG;
 IncidenceAttendee::IncidenceAttendee(QWidget *parent, IncidenceDateTime *dateTime, Ui::EventOrTodoDesktop *ui)
     : mUi(ui)
     , mParentWidget(parent)
-    , mConflictResolver(nullptr)
     , mDateTime(dateTime)
     , mStateDelegate(new AttendeeComboBoxDelegate(this))
     , mRoleDelegate(new AttendeeComboBoxDelegate(this))
@@ -94,7 +80,7 @@ IncidenceAttendee::IncidenceAttendee(QWidget *parent, IncidenceDateTime *dateTim
 
     setObjectName(QStringLiteral("IncidenceAttendee"));
 
-    AttendeeFilterProxyModel *filterProxyModel = new AttendeeFilterProxyModel(this);
+    auto *filterProxyModel = new AttendeeFilterProxyModel(this);
     filterProxyModel->setDynamicSortFilter(true);
     filterProxyModel->setSourceModel(mDataModel);
 
@@ -382,7 +368,7 @@ void IncidenceAttendee::checkIfExpansionIsNeeded(const KCalendarCore::Attendee &
     mGroupList.remove(attendee.uid());
 
     if (!fullname.isEmpty()) {
-        Akonadi::ContactGroupSearchJob *job = new Akonadi::ContactGroupSearchJob();
+        auto *job = new Akonadi::ContactGroupSearchJob();
         job->setQuery(Akonadi::ContactGroupSearchJob::Name, fullname);
         connect(job, &Akonadi::ContactGroupSearchJob::result, this,
                 &IncidenceAttendee::groupSearchResult);
@@ -393,7 +379,7 @@ void IncidenceAttendee::checkIfExpansionIsNeeded(const KCalendarCore::Attendee &
 
 void IncidenceAttendee::groupSearchResult(KJob *job)
 {
-    Akonadi::ContactGroupSearchJob *searchJob = qobject_cast<Akonadi::ContactGroupSearchJob *>(job);
+    auto *searchJob = qobject_cast<Akonadi::ContactGroupSearchJob *>(job);
     Q_ASSERT(searchJob);
 
     Q_ASSERT(mMightBeGroupJobs.contains(job));
@@ -424,7 +410,7 @@ void IncidenceAttendee::updateGroupExpand()
 void IncidenceAttendee::slotGroupSubstitutionPressed()
 {
     for (auto it = mGroupList.cbegin(), end = mGroupList.cend(); it != end; ++it) {
-        Akonadi::ContactGroupExpandJob *expandJob = new Akonadi::ContactGroupExpandJob(it.value(), this);
+        auto *expandJob = new Akonadi::ContactGroupExpandJob(it.value(), this);
         connect(expandJob, &Akonadi::ContactGroupExpandJob::result, this,
                 &IncidenceAttendee::expandResult);
         mExpandGroupJobs.insert(expandJob, it.key());
@@ -434,7 +420,7 @@ void IncidenceAttendee::slotGroupSubstitutionPressed()
 
 void IncidenceAttendee::expandResult(KJob *job)
 {
-    Akonadi::ContactGroupExpandJob *expandJob = qobject_cast<Akonadi::ContactGroupExpandJob *>(job);
+    auto *expandJob = qobject_cast<Akonadi::ContactGroupExpandJob *>(job);
     Q_ASSERT(expandJob);
     Q_ASSERT(mExpandGroupJobs.contains(job));
     const auto uid = mExpandGroupJobs.take(job);
@@ -1036,17 +1022,17 @@ void IncidenceAttendee::printDebugInfo() const
                                          << attendee.delegate()
                                          << attendee.delegator()
                                          << "; we have:";
-            for (int i = 0; i < newList.count(); ++i) {
-                KCalendarCore::Attendee attendee = newList[i];
-                qCDebug(INCIDENCEEDITOR_LOG) << "Attendee: " << attendee.email()
-                                             << attendee.name()
-                                             << attendee.status()
-                                             << attendee.RSVP()
-                                             << attendee.role()
-                                             << attendee.uid()
-                                             << attendee.cuType()
-                                             << attendee.delegate()
-                                             << attendee.delegator();
+            for (int i = 0, total = newList.count(); i < total; ++i) {
+                const KCalendarCore::Attendee newAttendee = newList[i];
+                qCDebug(INCIDENCEEDITOR_LOG) << "Attendee: " << newAttendee.email()
+                                             << newAttendee.name()
+                                             << newAttendee.status()
+                                             << newAttendee.RSVP()
+                                             << newAttendee.role()
+                                             << newAttendee.uid()
+                                             << newAttendee.cuType()
+                                             << newAttendee.delegate()
+                                             << newAttendee.delegator();
             }
 
             return;
