@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "incidencecategories.h"
@@ -34,7 +21,6 @@ using namespace IncidenceEditorNG;
 
 IncidenceCategories::IncidenceCategories(Ui::EventOrTodoDesktop *ui)
     : mUi(ui)
-    , mDirty(false)
 {
     setObjectName(QStringLiteral("IncidenceCategories"));
 
@@ -57,7 +43,7 @@ void IncidenceCategories::load(const KCalendarCore::Incidence::Ptr &incidence)
     mMissingCategories.clear();
 
     if (mLoadedIncidence) {
-        Akonadi::TagFetchJob *fetchJob = new Akonadi::TagFetchJob(this);
+        auto *fetchJob = new Akonadi::TagFetchJob(this);
         fetchJob->fetchScope().fetchAttribute<Akonadi::TagAttribute>();
         connect(fetchJob, &Akonadi::TagFetchJob::result, this, &IncidenceCategories::onTagsFetched);
     }
@@ -95,7 +81,7 @@ void IncidenceCategories::createMissingCategories()
 {
     for (const QString &category : qAsConst(mMissingCategories)) {
         Akonadi::Tag missingTag = Akonadi::Tag::genericTag(category);
-        Akonadi::TagCreateJob *createJob = new Akonadi::TagCreateJob(missingTag, this);
+        auto *createJob = new Akonadi::TagCreateJob(missingTag, this);
         connect(createJob, &Akonadi::TagCreateJob::result, this,
                 &IncidenceCategories::onMissingTagCreated);
     }
@@ -120,7 +106,7 @@ void IncidenceCategories::onTagsFetched(KJob *job)
         qCWarning(INCIDENCEEDITOR_LOG) << "Failed to load tags " << job->errorString();
         return;
     }
-    Akonadi::TagFetchJob *fetchJob = static_cast<Akonadi::TagFetchJob *>(job);
+    auto *fetchJob = static_cast<Akonadi::TagFetchJob *>(job);
     const Akonadi::Tag::List jobTags = fetchJob->tags();
 
     Q_ASSERT(mLoadedIncidence);
@@ -144,7 +130,7 @@ void IncidenceCategories::onMissingTagCreated(KJob *job)
         qCWarning(INCIDENCEEDITOR_LOG) << "Failed to create tag " << job->errorString();
         return;
     }
-    Akonadi::TagCreateJob *createJob = static_cast<Akonadi::TagCreateJob *>(job);
+    auto *createJob = static_cast<Akonadi::TagCreateJob *>(job);
     int count = mMissingCategories.removeAll(createJob->tag().name());
     Q_ASSERT(count > 0);
 
