@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "incidencedescription.h"
@@ -33,12 +20,12 @@ namespace IncidenceEditorNG {
 class IncidenceDescriptionPrivate
 {
 public:
-    IncidenceDescriptionPrivate() : mRichTextEnabled(false)
+    IncidenceDescriptionPrivate()
     {
     }
 
     QString mRealOriginalDescriptionEditContents;
-    bool mRichTextEnabled;
+    bool mRichTextEnabled = false;
 };
 }
 
@@ -155,7 +142,7 @@ void IncidenceDescription::setupToolBar()
     KActionCollection *collection = new KActionCollection(this);
     mUi->mDescriptionEdit->richTextComposer()->createActions(collection);
 
-    KToolBar *mEditToolBar = new KToolBar(mUi->mEditToolBarPlaceHolder);
+    auto *mEditToolBar = new KToolBar(mUi->mEditToolBarPlaceHolder);
     mEditToolBar->setToolButtonStyle(Qt::ToolButtonIconOnly);
     mEditToolBar->addAction(collection->action(QStringLiteral("format_text_bold")));
     mEditToolBar->addAction(collection->action(QStringLiteral("format_text_italic")));
@@ -181,9 +168,11 @@ void IncidenceDescription::setupToolBar()
     mEditToolBar->addSeparator();
 
     mEditToolBar->addAction(collection->action(QStringLiteral("format_painter")));
+    mEditToolBar->addSeparator();
+    mEditToolBar->addAction(collection->action(QStringLiteral("manage_link")));
     mUi->mDescriptionEdit->richTextComposer()->setEnableActions(false);
 
-    QGridLayout *layout = new QGridLayout(mUi->mEditToolBarPlaceHolder);
+    auto *layout = new QGridLayout(mUi->mEditToolBarPlaceHolder);
     layout->addWidget(mEditToolBar);
 #endif
 
